///
/// @file        CoProcLib.h
/// @copyright   Copyright (c) 2013 Toradex AG
/// $Author: gap $
/// $Rev: 1760 $ 
/// $Date: 2013-08-13 17:41:54 +0200 (Di, 13 Aug 2013) $
/// @brief       Library to provide access to the ARM Coprocessor registers  
/// 
/// @target      PXAxxx, T20
///

#ifndef __COPROC_LIB_H__
#define __COPROC_LIB_H__

#ifdef __cplusplus
extern "C" {
#endif

#define CPL_VER_MAJ     2
#define CPL_VER_MIN     1
#define CPL_VER_BUILD   0

/// SoC family Type
#define PXA 1
#define TEG 2

// Defines for getPROCID
#define TYPE_PXA270     0x11
#define TYPE_MONAHANS   0x02
#define TYPE_PXA320     0x02
#define TYPE_PXA300XT   0x07
#define TYPE_PXA300     0x08
#define TYPE_PXA310     0x09
#define TYPE_TEGRA2     0x411FC09
#define TYPE_TEGRA3     0x412FC09

// Defines for getModuleFamilyID
#define    MODULE_FAMILY_COLIBRI    0
#define    MODULE_FAMILY_APALIS     1

/*
Get CLKCFG (Coprocessor 14, cr6)
Core Clock Configuration
*/
DWORD getCLKCFG();

/*
Sets CLKCFG (Coprocessor 14, cr6)
Core Clock Configuration
*/
void setCLKCFG(DWORD);

/*
Get PWRMODE (Coprocessor 14, cr7)
Power Modes
*/
DWORD getPWRMODE();

/*
Set PWRMODE (Coprocessor 14, cr7)
Power Modes
*/
void setPWRMODE(DWORD);

/*
Gets CPUID (Coprocessor 15, cr0)
Prozessor information
*/
DWORD getCPUID();

/*
Get Processor ID
Use this function to dedect on which processor your programm is  running
*/
DWORD getPROCID();

/*
Check if L2 cache are enabled
TRUE: Enabled False: disabled
*/
DWORD getL2Enabled();

/*
Description:        Returns the library Version
Parameter:
Out-Parameter:
- pVerMaj:          Returns the major version number. Set this parameter to NULL if not required.
- pVerMin:          Returns the minor version number. Set this parameter to NULL if not required.
- pBuild:           Returns the build number.         Set this parameter to NULL if not required.
Return Value:       No return value.
*/
void CPLGetLibVersion(DWORD *pVerMaj, DWORD *pVerMin, DWORD *pBuild);

//-------------------------------------------------------------------------
/// To findout SoC family type
/// @param[out] CPU_TYPE: choose between soc family i.e PXA or tegra
DWORD GetSoCType();

DWORD getModuleFamily();

#ifdef __cplusplus
}
#endif

#endif
